==> bpm-api-zhiyuan-1.0.15-20251024.104951-2-sources.jar: com/elitesland/tw/tw5/api/bpm/common/service/rpc/BpmService.java <==
package com.elitesland.tw.tw5.api.bpm.common.service.rpc;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitesland.tw.tw5.api.bpm.common.payload.BpmPayload;
import com.elitesland.tw.tw5.api.bpm.common.payload.BpmUserRefOaPayload;
import com.elitesland.tw.tw5.api.bpm.common.vo.BpmVO;
import com.elitesland.tw.tw5.api.bpm.weavere9.payload.OaDoRejectRequestPayload;
import com.elitesland.tw.tw5.api.bpm.weavere9.payload.OaGetRequestLogPayload;
import com.elitesland.tw.tw5.api.bpm.weavere9.payload.OaWithdrawRequestPayload;
import com.elitesland.tw.tw5.api.bpm.weavere9.vo.RequestLogVO;
import com.elitesland.tw.tw5.api.bpm.weavere9.vo.WeavereE9BaseVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(value = "bpm", path = "rpc/bpm/common")
public interface BpmService {

    @PostMapping("submit")
    @ApiOperation("提交流程")
    ApiResult<BpmVO> submit(@RequestBody BpmPayload payload);

    @PostMapping("getRequestLog")
    @ApiOperation("流程实例：获取流程意见（对外）")
    public ApiResult<List<RequestLogVO>> getRequestLog(@RequestBody OaGetRequestLogPayload payload);

    @PostMapping("withdrawRequest")
    @ApiOperation("流程实例：流程撤回（对外）")
    public ApiResult<WeavereE9BaseVO> withdrawRequest(@RequestBody OaWithdrawRequestPayload payload);

    @PostMapping("doForceDrawBack")
    @ApiOperation("流程实例：强制收回（对外）")
    public ApiResult<WeavereE9BaseVO> doForceDrawBack(@RequestBody OaDoRejectRequestPayload payload);

    @PostMapping("getRequestStatus")
    @ApiOperation("流程实例：获取流程状态数据（对外）")
    public ApiResult<WeavereE9BaseVO> getRequestStatus(@RequestBody OaDoRejectRequestPayload payload);

    @GetMapping("getOaUserIdByOaNo")
    @ApiOperation("根据OA工号获取OA用户id")
    ApiResult<String> getOaUserIdByOaNo(@RequestParam String workCode);

    @PostMapping("syncUserRefByOa")
    @ApiOperation("同步用户关系")
    ApiResult syncUserRefByOa(@RequestParam String sourceCode,@RequestParam String targetCode,@RequestBody List<BpmUserRefOaPayload> refList);

}

==> bpm-api-zhiyuan-1.0.16-20251114.015606-2-sources.jar: com/elitesland/tw/tw5/api/bpm/common/service/rpc/BpmService.java <==
package com.elitesland.tw.tw5.api.bpm.common.service.rpc;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitesland.tw.tw5.api.bpm.common.payload.BpmPayload;
import com.elitesland.tw.tw5.api.bpm.common.payload.BpmUserRefOaPayload;
import com.elitesland.tw.tw5.api.bpm.common.vo.BpmVO;
import com.elitesland.tw.tw5.api.bpm.weavere9.payload.*;
import com.elitesland.tw.tw5.api.bpm.weavere9.vo.RequestLogVO;
import com.elitesland.tw.tw5.api.bpm.weavere9.vo.WeavereE9BaseVO;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.util.List;

@FeignClient(value = "bpm", path = "rpc/bpm/common")
public interface BpmService {

    @PostMapping("submit")
    @ApiOperation("提交流程")
    ApiResult<BpmVO> submit(@RequestBody BpmPayload payload);

    @PostMapping("getRequestLog")
    @ApiOperation("流程实例：获取流程意见（对外）")
    public ApiResult<List<RequestLogVO>> getRequestLog(@RequestBody OaGetRequestLogPayload payload);

    @PostMapping("withdrawRequest")
    @ApiOperation("流程实例：流程撤回（对外）")
    public ApiResult<WeavereE9BaseVO> withdrawRequest(@RequestBody OaWithdrawRequestPayload payload);

    @PostMapping("doForceDrawBack")
    @ApiOperation("流程实例：强制收回（对外）")
    public ApiResult<WeavereE9BaseVO> doForceDrawBack(@RequestBody OaDoRejectRequestPayload payload);

    @PostMapping("getRequestStatus")
    @ApiOperation("流程实例：获取流程状态数据（对外）")
    public ApiResult<WeavereE9BaseVO> getRequestStatus(@RequestBody OaDoRejectRequestPayload payload);

    @PostMapping("getRequestFlowChart")
    @ApiOperation("流程实例：获取流程图链接(对外)")
    public ApiResult<WeavereE9BaseVO> getRequestFlowChart(@RequestBody OaRequestFlowChartPayload payload);

    @PostMapping("getRequestOperatorInfo")
    @ApiOperation("流程实例：获取流程流转数据（对外）")
    public ApiResult<WeavereE9BaseVO> getRequestOperatorInfo(@RequestBody RequestOperatorInfoPayload payload);


    @GetMapping("getOaUserIdByOaNo")
    @ApiOperation("根据OA工号获取OA用户id")
    ApiResult<String> getOaUserIdByOaNo(@RequestParam String workCode);

    @PostMapping("syncUserRefByOa")
    @ApiOperation("同步用户关系")
    ApiResult syncUserRefByOa(@RequestParam String sourceCode,@RequestParam String targetCode,@RequestBody List<BpmUserRefOaPayload> refList);

}
